@@ -1,5 +1,5 @@
 """Exceptions for 2N library."""
-from typing import Enum
+from enum import Enum
 from dataclasses import dataclass
 
 # Internal errors
